<?php
defined( 'ABSPATH' ) or die();

function wpza_gui__metabox_items_register() {
	add_meta_box( 'wpza-gui-metabox-items', 'Invoice Details', 'wpza_gui__metabox_items_output', 'wpza_gui__invoice', 'normal', 'high' );
}
add_action( 'add_meta_boxes', 'wpza_gui__metabox_items_register' );

function wpza_gui__metabox_items_output() {
	global $post;
	$metabox_group = get_post_meta( $post->ID, 'wpza_gui__metabox_items_group', true );
	wp_nonce_field( 'wpza_gui__metabox_items_group_nonce', 'wpza_gui__metabox_items_group_nonce' );
	if ( get_option( 'wpza_gui__plugin_settings_currency' ) ) {
		$currency = get_option( 'wpza_gui__plugin_settings_currency' );
	} else {
		$currency = '$';
	}
	?>
	    <script type="text/javascript">
	    jQuery(document).ready(function( $ ){
	        $( '.row' ).on('click', function() {
	            var row = $ ( 'table#metabox-items-table .empty-row' ).clone( true );
	            row.removeClass( 'empty-row' );
	            row.insertBefore( 'table#metabox-items-table tbody>tr:last' );
	            return false;
	        });
	        $( 'table#metabox-items-table .remove-row' ).on('click', function() {
	            $(this).parents( 'tr' ).remove();
	            return false;
	        });
	    });
		</script>
		<table id="metabox-items-table" width="100%">
			<thead>
				<tr>
					<td width="50%">Item</td>
					<td width="25%">Quantity</td>
					<td width="25%">Price Per Item (<?php echo esc_attr( $currency ); ?>)</td>
				</tr>
			</thead>
			<tbody>
			<?php
			if( $metabox_group ) {
					foreach( $metabox_group as $field ) {
				?>
			    <tr>
			    	<td>
			    		<input type="text" placeholder="Item" name="item[]" value="<?php if( $field['item'] != '' ) { echo esc_attr( $field['item'] ); } ?>" style="width: 100%;" />
			    	</td>
			    	<td>
			        	<input type="number" step="any" placeholder="Quantity" name="quantity[]" value="<?php if( $field['quantity'] != '' ) { echo esc_attr( $field['quantity'] ); } ?>" style="width: 100%;" />
			    	</td>
			    	<td>
			        	<input type="number" step="any" placeholder="Price Per Item" name="price[]" value="<?php if( $field['price'] != '' ) { echo esc_attr( $field['price'] ); } ?>" style="width: 100%;" />
			    	</td>
			    	<td>
			      		<a class="button remove-row" href="#1">Remove</a>
			    	</td>
			    </tr>
				<?php
				}
			} else {
			?>
			<tr>
				<td> 
					<input type="text" placeholder="Item" title="Item" name="item[]" style="width: 100%;" />
				</td>
				<td> 
					<input type="number" step="any" placeholder="Quantity" name="quantity[]" style="width: 100%;" />
				</td>
				<td> 
					<input type="number" step="any" placeholder="Price Per Item" name="price[]" style="width: 100%;" />
				</td>
				<td>
					<a class="button button-disabled" href="#">Remove</a>
				</td>
			</tr>
			<?php } ?>
			<tr class="empty-row">
				<td>
					<input type="text" placeholder="Item" name="item[]" style="width: 100%;" />
				</td>
				<td> 
					<input type="number" step="any" placeholder="Quantity" name="quantity[]" style="width: 100%;" />
				</td>
				<td>
					<input type="number" step="any" placeholder="Price Per Item" name="price[]" style="width: 100%;" />
				</td>
				<td>
					<a class="button remove-row" href="#">Remove</a>
				</td>
			</tr>
			</tbody>
		</table>
		<p><a class="row button" href="#">Add Item</a></p>
	<?php
}

function wpza_gui__metabox_items_save( $post_id ) {
    if( ! isset( $_POST['wpza_gui__metabox_items_group_nonce'] ) || ! wp_verify_nonce( $_POST['wpza_gui__metabox_items_group_nonce'], 'wpza_gui__metabox_items_group_nonce' ) ) {
        return;
    }

    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }

    if( ! current_user_can( 'edit_post', $post_id ) ) {
        return;
    }

    $items_old = get_post_meta( $post_id, 'wpza_gui__metabox_items_group', true );
    $user_old = get_post_meta( $post_id, 'invoice_user', true );
    $items_new = array();
    $invoice_items = filter_var_array( $_POST['item'], FILTER_SANITIZE_STRING );
    $invoice_prices = filter_var_array( $_POST['price'], FILTER_SANITIZE_STRING );
    $invoice_quantities = filter_var_array( $_POST['quantity'], FILTER_SANITIZE_STRING );
 	$count = count( $invoice_items );
	for( $i = 0; $i < $count; $i++ ) {
        if( $invoice_items[$i] != '' ) :
        	$items_new[$i]['item'] = stripslashes( strip_tags( $invoice_items[$i] ) );
        	$items_new[$i]['price'] = stripslashes( $invoice_prices[$i] );
        	$items_new[$i]['quantity'] = stripslashes( $invoice_quantities[$i] );
        endif;
    }
    if( ! empty( $items_new ) && $items_new != $items_old ) {
        update_post_meta( $post_id, 'wpza_gui__metabox_items_group', $items_new );
        if ( ! empty( $user_old ) ) {
        	wpza_gui__mail_updated_items( $post_id );
    	}
    }
    elseif( empty( $items_new ) && $items_old ) {
        delete_post_meta( $post_id, 'wpza_gui__metabox_items_group', $items_old );
        wpza_gui__mail_updated_items( $post_id );
    }
}
add_action( 'save_post', 'wpza_gui__metabox_items_save', 1 );